Index: fetch_configs/ios_internal.py |
diff --git a/fetch_configs/chromium.py b/fetch_configs/ios_internal.py |
similarity index 67% |
copy from fetch_configs/chromium.py |
copy to fetch_configs/ios_internal.py |
index d461aa0fc5e0d556f88363dbed0ad95cdd779494..da730982ade21dfee59de4c74e998d7e2bef1344 100644 |
--- a/fetch_configs/chromium.py |
+++ b/fetch_configs/ios_internal.py |
@@ -1,4 +1,4 @@ |
-# Copyright (c) 2013 The Chromium Authors. All rights reserved. |
+# Copyright 2016 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
@@ -9,26 +9,26 @@ import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Chromium(config_util.Config): |
- """Basic Config class for Chromium.""" |
+class IOSInternal(config_util.Config): |
+ """Basic Config class for Chrome on iOS.""" |
@staticmethod |
def fetch_spec(props): |
- url = 'https://chromium.googlesource.com/chromium/src.git' |
- solution = { 'name' :'src', |
+ url = 'https://chrome-internal.googlesource.com/chrome/ios_internal.git' |
+ solution = { 'name' :'src/ios_internal', |
'url' : url, |
- 'deps_file': '.DEPS.git', |
+ 'deps_file': 'DEPS', |
'managed' : False, |
'custom_deps': {}, |
'safesync_url': '', |
} |
- if props.get('webkit_revision', '') == 'ToT': |
- solution['custom_vars'] = {'webkit_revision': ''} |
spec = { |
'solutions': [solution], |
} |
if props.get('target_os'): |
spec['target_os'] = props['target_os'].split(',') |
+ else: |
+ spec['target_os'] = ['ios'] |
if props.get('target_os_only'): |
spec['target_os_only'] = props['target_os_only'] |
return { |
@@ -42,7 +42,7 @@ class Chromium(config_util.Config): |
def main(argv=None): |
- return Chromium().handle_args(argv) |
+ return IOSInternal().handle_args(argv) |
if __name__ == '__main__': |